pub struct SellerDealPaymentEvent {
pub posted_date: Option<String>,
pub deal_id: Option<String>,
pub deal_description: Option<String>,
pub event_type: Option<String>,
pub fee_type: Option<String>,
pub fee_amount: Option<Box<Currency>>,
pub tax_amount: Option<Box<Currency>>,
pub total_amount: Option<Box<Currency>>,
}Expand description
SellerDealPaymentEvent : An event linked to the payment of a fee related to the specified deal.
Fields
posted_date: Option<String>deal_id: Option<String>The unique identifier of the deal.
deal_description: Option<String>The internal description of the deal.
event_type: Option<String>The type of event: SellerDealComplete.
fee_type: Option<String>The type of fee: RunLightningDealFee.
fee_amount: Option<Box<Currency>>tax_amount: Option<Box<Currency>>total_amount: Option<Box<Currency>>Implementations
sourceimpl SellerDealPaymentEvent
impl SellerDealPaymentEvent
sourcepub fn new() -> SellerDealPaymentEvent
pub fn new() -> SellerDealPaymentEvent
An event linked to the payment of a fee related to the specified deal.